==> Statemate4.6.1.4Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Quick Reference/wwhdata/js/search/pairs/pair20.js <==
function FileData_Pairs(x)
{
x.t("example","arc");
x.t("atan2d","(x)");
x.t("lists","trigonometric");
x.t("table","lists");
x.t("atan","(x)");
x.t("atan2","(x)");
x.t("tables","predefined");
x.t("tan","(x)");
x.t("type","return");
x.t("type","meaning");
x.t("cosd","(x)");
x.t("rational","statemate");
x.t("radians","atan2");
x.t("radians","tan");
x.t("radians","sin");
x.t("radians","acosd");
x.t("radians","asind");
x.t("radians","two");
x.t("sind","(x)");
x.t("asin","(x)");
x.t("sine","radians");
x.t("sine","sind");
x.t("sine","degrees");
x.t("cosh","(x)");
x.t("arc","sine");
x.t("arc","cosine");
x.t("arc","tangent");
x.t("sin","(x)");
x.t("sinh","(x)");
x.t("argument","type");
x.t("degrees","atan2d");
x.t("degrees","atan");
x.t("degrees","asin");
x.t("degrees","cosh");
x.t("degrees","sinh");
x.t("degrees","tanh");
x.t("degrees","two");
x.t("parameters","example");
x.t("functions","functions");
x.t("functions","supported");
x.t("functions","operators");
x.t("functions","trigonometric");
x.t("functions","following");
x.t("supported","rational");
x.t("operators","switch");
x.t("function","argument");
x.t("acosd","(x)");
x.t("asind","(x)");
x.t("switch","cases");
x.t("acos","(x)");
x.t("tand","(x)");
x.t("return","type");
x.t("(x)","sine");
x.t("(x)","arc");
x.t("(x)","hyperbolic");
x.t("(x)","cosine");
x.t("(x)","tangent");
x.t("cos","(x)");
x.t("hyperbolic","sine");
x.t("hyperbolic","cosine");
x.t("hyperbolic","tangent");
x.t("trigonometric","functions");
x.t("tanh","(x)");
x.t("(a1/a2)","cos");
x.t("(a1/a2)","atand");
x.t("cosine","cosd");
x.t("cosine","radians");
x.t("cosine","degrees");
x.t("meaning","acos");
x.t("statemate","function");
x.t("predefined","functions");
x.t("two","parameters");
x.t("cases","truth");
x.t("truth","tables");
x.t("atand","(x)");
x.t("following","table");
x.t("tangent","radians");
x.t("tangent","degrees");
x.t("tangent","tand");
x.t("tangent","(a1/a2)");
}

==> Statemate4.6.1.10Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Quick Reference/wwhdata/js/search/pairs/pair20.js <==
function FileData_Pairs(x)
{
x.t("example","arc");
x.t("atan2d","arc");
x.t("lists","trigonometric");
x.t("table","lists");
x.t("atan","(x)");
x.t("atan2","arc");
x.t("tables","predefined");
x.t("tan","(x)");
x.t("type","return");
x.t("type","meaning");
x.t("cosd","(x)");
x.t("rational","statemate");
x.t("radians","atan2");
x.t("radians","tan");
x.t("radians","sin");
x.t("radians","acosd");
x.t("radians","asind");
x.t("radians","two");
x.t("sind","(x)");
x.t("asin","(x)");
x.t("sine","radians");
x.t("sine","sind");
x.t("sine","degrees");
x.t("cosh","(x)");
x.t("arc","sine");
x.t("arc","cosine");
x.t("arc","tangent");
x.t("sin","(x)");
x.t("sinh","(x)");
x.t("argument","type");
x.t("degrees","atan2d");
x.t("degrees","atan");
x.t("degrees","asin");
x.t("degrees","cosh");
x.t("degrees","sinh");
x.t("degrees","tanh");
x.t("degrees","two");
x.t("parameters","example");
x.t("functions","functions");
x.t("functions","supported");
x.t("functions","operators");
x.t("functions","trigonometric");
x.t("functions","following");
x.t("supported","rational");
x.t("operators","switch");
x.t("function","argument");
x.t("acosd","(x)");
x.t("asind","(x)");
x.t("switch","cases");
x.t("acos","(x)");
x.t("tand","(x)");
x.t("return","type");
x.t("(x)","sine");
x.t("(x)","arc");
x.t("(x)","hyperbolic");
x.t("(x)","cosine");
x.t("(x)","tangent");
x.t("cos","(x)");
x.t("hyperbolic","sine");
x.t("hyperbolic","cosine");
x.t("hyperbolic","tangent");
x.t("trigonometric","functions");
x.t("tanh","(x)");
x.t("cosine","cosd");
x.t("cosine","radians");
x.t("cosine","degrees");
x.t("meaning","acos");
x.t("statemate","function");
x.t("predefined","functions");
x.t("two","parameters");
x.t("cases","truth");
x.t("truth","tables");
x.t("atand","(x)");
x.t("following","table");
x.t("tangent","radians");
x.t("tangent","degrees");
x.t("tangent","tand");
x.t("tangent","(x/y)");
x.t("(x/y)","cos");
x.t("(x/y)","atand");
}
